@@ -125,6 +125,9 @@ RESOURCEBUSY = 'ResourceBusy'
 # Occupied resource.
 RESOURCEINUSE = 'ResourceInUse'
 
+# The cloud disk is being migrated. Try again later.
+RESOURCEINUSE_DISKMIGRATING = 'ResourceInUse.DiskMigrating'
+
 # The cloud disk is being rolled back. Please try again later.
 RESOURCEINUSE_DISKROLLBACKING = 'ResourceInUse.DiskRollbacking'
 
